==> qucs_0.0.7.orig.tar.gz: qucs-0.0.7.orig/qucs/diagrams/rect3ddiagram.h <==
/***************************************************************************
                              rect3ddiagram.h
                             -----------------
    begin                : Sat Mar 5 2005
    copyright            : (C) 2005 by Michael Margraf
    email                : michael.margraf@alumni.tu-berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RECT3DDIAGRAM_H
#define RECT3DDIAGRAM_H

#include "diagram.h"


struct tPoint3D {
  int   x, y;
  float z;
  int   No;
};

//#define HIDDENLINE

class Rect3DDiagram : public Diagram  {
public:
  Rect3DDiagram(int _cx=0, int _cy=0);
 ~Rect3DDiagram();


  Diagram* newOne();
  static Element* info(QString&, char* &, bool getNewOne=false);
  int  calcDiagram();
  void calcLimits();
  int  calcAxis(Axis*, int, int, int, int, bool);
  void calcData(Graph *g);
  void calcCoordinate(double* &, double* &, double* &, int*, int*, Axis*);

  void createAxisLabels() {};   // labels created during calcDiagram
  bool insideDiagram(int, int);
  void clip(int* &);

  tPoint3D *Mem;   // memory for all points during hidden line algorithm
  tPoint3D *pMem;  // current position in "Mem"
  void removeHiddenLines();

private:
  void   calcCoefficients();
  double calcX_2D(double, double, double);
  double calcY_2D(double, double, double);
  double calcZ_2D(double, double, double);

  void calcLine(tPoint3D* &, tPoint3D*, tPoint3D* &, tPoint3D* &);
  void calcCoordinate3D(double, double, double, double, tPoint3D*);

  int xorig, yorig;    // where is the 3D origin with respect to cx/cy
  double cxx, cxy, cxz, cyx, cyy, cyz, czx, czy, czz; // coefficients 3D -> 2D
  double scaleX, scaleY;
};

#endif

==> qucs_0.0.9.orig.tar.gz: qucs-0.0.9.orig/qucs/diagrams/rect3ddiagram.h <==
/***************************************************************************
                              rect3ddiagram.h
                             -----------------
    begin                : Sat Mar 5 2005
    copyright            : (C) 2005 by Michael Margraf
    email                : michael.margraf@alumni.tu-berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RECT3DDIAGRAM_H
#define RECT3DDIAGRAM_H

#include "diagram.h"


struct tPoint3D {
  int   x, y;
  int   No, done;
};

struct tPointZ {
  float z;
  int   No, NoCross;
};

struct tBound {
  int min, max;
};


class Rect3DDiagram : public Diagram  {
public:
  Rect3DDiagram(int _cx=0, int _cy=0);
 ~Rect3DDiagram();


  Diagram* newOne();
  static Element* info(QString&, char* &, bool getNewOne=false);
  int  calcDiagram();
  void calcLimits();
  void calcCoordinate(double* &, double* &, double* &, int*, int*, Axis*);

  void createAxisLabels();
  bool insideDiagram(int, int);

  tPoint3D *Mem;   // memory for all points during hidden line algorithm
  tPoint3D *pMem;  // current position in "Mem"


protected:
  void calcData(Graph*);

private:
  int  calcAxis(Axis*, int, int, double, double, bool);
  void createAxis(Axis*, bool, int, int, int, int);

  void   calcCoefficients();
  int    calcCross(int*, int*);
  double calcX_2D(double, double, double);
  double calcY_2D(double, double, double);
  double calcZ_2D(double, double, double);

  bool isHidden(int, int, tBound*, char*);
  void enlargeMemoryBlock(tPoint3D* &);
  void calcLine(tPoint3D* &, tPoint3D* &, tBound*, char*);
  void calcCoordinate3D(double, double, double, double, tPoint3D*, tPointZ*);
  void removeHiddenLines(char*, tBound*);
  void removeHiddenCross(int, int, int, int, char*, tBound*);

  int  xorig, yorig; // where is the 3D origin with respect to cx/cy
  double cxx, cxy, cxz, cyx, cyy, cyz, czx, czy, czz; // coefficients 3D -> 2D
  double scaleX, scaleY;
};

#endif
